function main ()
{
  System.print ("result1=", add (1, 2, 3), "\n");
  System.print ("result2=", add (1, 2, 3.5), "\n");
}

main ();


/*
Local variables:
mode: c
End:
*/
